<TS language="zh_CN" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>关于格雷德币</translation>
    </message>
    <message>
        <source>&lt;b&gt;Gridcoin&lt;/b&gt; </source>
        <translation>&lt;b&gt;格雷德币&lt;/b&gt; </translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>创建新地址</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建(&amp;N)</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>复制当前选中的地址到系统剪贴板</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>复制(&amp;C)</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>显示二维码(&amp;Q)</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>对信息进行签名以证明您对该格雷德币地址的所有权</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>签名(&amp;M)</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>验证信息以保证其经过指定格雷德币地址的签名</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>验证消息(&amp;V)</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>从列表中删除选中的地址</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>地址簿</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>这是您用来接收支付的格雷德币地址列表。为不同的支付方建立不同的地址以便于了解支付来源。</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>复制标签(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>导出地址簿数据</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>导出时发生错误</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>无法写入文件 %1 。</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(没有标签)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>密码对话框</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>输入密码</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>新密码</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>重复新密码</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>在系统允许的情况下用于防止sendmoney欺诈，并未提供真正的安全防护措施。</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>仅用于权益增值</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>输入钱包的新密码。&lt;br/&gt;使用的密码请至少包含&lt;b&gt;10个以上随机字符&lt;/&gt;，或者是&lt;b&gt;8个以上的单词&lt;/b&gt;。</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>加密钱包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>此操作需要您首先使用密码解锁该钱包。</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>解锁钱包</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>更改密码</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>请输入该钱包的旧密码与新密码。</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>确认加密钱包</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>警告：如果您丢失了加密该钱包的密码，其中所有的格雷德币将会丢失！</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>您确定需要为钱包加密吗？</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>钱包已加密</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>格雷德币客户端即将关闭以完成加密过程。请记住，加密钱包并不能完全防止您的电子货币被入侵您计算机的木马软件盗窃。</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>重要提示：您以前备份的钱包文件应该替换成最新生成的加密钱包文件（重新备份）。从安全性上考虑，您以前备份的未加密的钱包文件，在您使用新的加密钱包后将无效，请重新备份。</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>钱包加密失败</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>由于一个本地错误，加密钱包的操作已经失败。您的钱包没能被加密。</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>密码不匹配。</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>钱包解锁失败</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>用于解密钱包的密码不正确。</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>修改钱包密码成功。</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>警告：大写锁定键处于打开状态！</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>发生致命错误。格雷德币不再安全，即将退出。</translation>
    </message>
    <message>
        <source>Gridcoin</source>
        <translation>格雷德币</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>钱包</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>概况(&amp;O)</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>显示钱包概况</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>发送(&amp;S)</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>向指定的地址发送格雷德币</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>接收(&amp;R)</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>显示用于接收支付的地址列表</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>查看交易历史</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>管理已储存的地址和标签</translation>
    </message>
    <message>
        <source>&amp;Voting</source>
        <translation>&amp;投票</translation>
    </message>
    <message>
        <source>Voting</source>
        <translation>投票</translation>
    </message>
    <message>
        <source>&amp;Block Explorer</source>
        <translation>&amp;区块浏览器</translation>
    </message>
    <message>
        <source>Block Explorer</source>
        <translation>区块浏览器</translation>
    </message>
    <message>
        <source>&amp;Exchange</source>
        <translation>交易所</translation>
    </message>
    <message>
        <source>Web Site</source>
        <translation>网站</translation>
    </message>
    <message>
        <source>&amp;Web Site</source>
        <translation>&amp;网站</translation>
    </message>
    <message>
        <source>&amp;GRC Chat Room</source>
        <translation>&amp;GRC聊天室</translation>
    </message>
    <message>
        <source>GRC Chatroom</source>
        <translation>GRC聊天室</translation>
    </message>
    <message>
        <source>Gridcoin rewards distributed computing with BOINC</source>
        <translation>格雷德币给BOINC分布式计算参与者提供报酬</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>退出(&amp;X)</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>退出程序</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>关于格雷德币(&amp;A)</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>显示关于格雷德币的信息</translation>
    </message>
    <message>
        <source>&amp;Diagnostics</source>
        <translation>&amp;诊断</translation>
    </message>
    <message>
        <source>Diagnostics</source>
        <translation>诊断</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>选项(&amp;O)...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>更改格雷德币设置选项</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>显示 / 隐藏(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>加密钱包(&amp;E)...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>更改密码(&amp;C)...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>更改钱包加密口令</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>解锁钱包(&amp;U)</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>解锁钱包</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>锁定钱包(&amp;L)</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>锁定钱包</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>消息签名(&amp;M)...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>验证消息(&amp;V)...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>导出(&amp;E)</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>导出当前标签页的数据</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>调试窗口(&amp;D)</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>打开调试和诊断控制台</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>设置(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Community</source>
        <translation>社区</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <source>[testnet]</source>
        <translation>[测试网络]</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>格雷德币客户端</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>已是最新</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>更新中...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>最新收到的区块产生于 %1。</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>交易数据量超限。您仍可发送这笔交易，只需为节点确认您的交易以及支持网络运行提供%1的交易费。您希望付费吗？</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>确认交易费</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>发送交易</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>流入交易</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI处理</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>无法解析 URI 地址！可能是因为格雷德币地址无效，或是 URI 参数格式错误。</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>钱包已被&lt;b&gt;加密&lt;/b&gt;，当前为&lt;b&gt;锁定&lt;/b&gt;状态</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>备份钱包</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>钱包数据(*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>备份失败</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>存储地址列表到新位置时发生错误。</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>网络警报</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>数量：</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>比特数：</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>金额：</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>费用：</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>货币支配</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>输出：</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>加上费用后:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>零钱 : </translation>
    </message>
    <message>
        <source>Tree &amp;mode</source>
        <translation>树形模式</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>金额</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>确认数</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>已确认</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>复制金额</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>复制转账ID</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>复制数量</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>复制费用</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>复制转账金额加费用</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>复制比特数</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>复制低级输出</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>复制零钱</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>若转账数据量大于10000比特，本标签会变红。
            
这意味着要求至少每Kb%1的费用。
            
每次输入可能有+/-1字节的波动。</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>若任意收款方收到的金额小于%1，本标签会变红。
            
这意味着要求至少%2的费用。
            
金额少于最小广播费用的0.546倍的交易将显示为DUST。</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>若更改少于%1，本标签会变红。
这意味着要求至少%2的费用。</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>来自%1的零钱 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(零钱)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>编辑地址</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>标签(&amp;L)</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>与此地址条目关联的标签</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>该地址与地址簿中的条目已关联，无法作为发送地址编辑。</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>地址(&amp;A)</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>新接收地址</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>新发送地址</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>编辑接收地址</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>编辑发送地址</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>您输入的 "%1" 不是合法的格雷德币地址。</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>输入的地址 "%1" 已经存在于地址薄。</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>无法解锁钱包</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>密钥创建失败。</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>用途：</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>命令行选项</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>主选项(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>网络(&amp;N)</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>使用 &amp;UPnP 映射端口</translation>
    </message>
    <message>
        <source>Reser&amp;ve</source>
        <translation>保留</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>登录系统后自动启动格雷德币。</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>系统登录时启动格雷德币(&amp;S)</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>自动在路由器中打开比特币端口。只有当您的路由器支持并开启 UPnP 选项时此功能才有效。</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>代理服务器的IP地址(例如127.0.0.1)</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>端口(&amp;P)：</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>代理端口(例如9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>当窗口关闭时程序最小化而不是退出。当使用该选项时，程序只能通过在菜单中选择退出来关闭。</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>设置语言选项。需重启客户端软件才能生效。</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>风格：</translation>
    </message>
    <message>
        <source>Choose a stylesheet to change the look of the wallet.</source>
        <translation>选择样式表以更改钱包外观。</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>在转账列表中是否显示格雷德币地址。</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>在转账列表中显示地址(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>窗口(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>应用(&amp;A)</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>最小化窗口后只显示一个托盘标志</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>最小化到托盘而非任务栏(&amp;M)</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>关闭时最小化(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>显示(&amp;D)</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>使用界面语言(&amp;L)：</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>格雷德币金额单位(&amp;U)：</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>选择显示及发送货币时使用的最小单位</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确定(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>轻</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>这个设置将在格雷德币重启后生效。</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>提供的代理地址无效。</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>表单</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>可使用的余额：</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>您当前可使用的余额</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>未成熟的：</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>钱包</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>现在显示的消息可能是过期的. 在连接上格雷德币网络节点后，您的钱包将自动与网络同步，但是这个过程还没有完成。</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>尚未确认的交易总额, 未计入当前余额</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>总计：</translation>
    </message>
    <message>
        <source>Total mined coins that have not yet matured.</source>
        <translation>全部已挖到而未成熟的货币。</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>您当前的总余额</translation>
    </message>
    <message>
        <source>Blocks:</source>
        <translation>区块数：</translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation>难度：</translation>
    </message>
    <message>
        <source>Net Weight:</source>
        <translation>全网权重：</translation>
    </message>
    <message>
        <source>Magnitude:</source>
        <translation>权重</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>状态：</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>二维码对话框</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>要求支付</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>标签：</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>消息：</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>金额:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>另存为(&amp;S)...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>将URI编码为二维码时出现错误。</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>输入的金额无效，请检查。</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>得到的URI超长，请尝试缩减标签/消息中的文字。</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>保存二维码</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>不可用</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>客户端版本</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>信息(&amp;I)</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>启动时间</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>连接数</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>区块链</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>当前区块数</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>上个区块的时间</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>打开(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;清除</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>控制台(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;网络流量</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>总计</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>输入：</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>输出：</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>调试日志文件</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>清空控制台</translation>
    </message>
    <message>
        <source>Gridcoin - Debug Console</source>
        <translation>格雷德币 - 调试控制台</translation>
    </message>
    <message>
        <source>Boost version</source>
        <translation>加速器版本</translation>
    </message>
    <message>
        <source>Gridcoin Core:</source>
        <translation>格雷德币核心：</translation>
    </message>
    <message>
        <source>Network:</source>
        <translation>网络：</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>测试网络</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>预计区块总数</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>在当前数据目录打开调试日志文件。大的日志文件需要几秒钟。</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>命令行选项</translation>
    </message>
    <message>
        <source>Show the Gridcoin help message to get a list with possible Gridcoin command-line options.</source>
        <translation>显示格雷德币帮助信息以得到格雷德币命令行可能选项的列表。</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>显示(&amp;S)</translation>
    </message>
    <message>
        <source>OpenSSL version</source>
        <translation>OpenSSL版本</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>客户端名称</translation>
    </message>
    <message>
        <source>Welcome to the Gridcoin RPC console! </source>
        <translation>欢迎来到格雷德币RPC控制台！</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>使用上下方向键浏览历史,  &lt;b&gt;Ctrl-L&lt;/b&gt;清除屏幕。</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>使用 &lt;b&gt;help&lt;/b&gt; 命令显示帮助信息。</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 分</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 时</translation>
    </message>
    <message>
        <source>%1 h %2 m</source>
        <translation>%1 时 %2 分</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>付款</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>输入...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>已自动选择</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>金额不足</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>数量</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>字节数：</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>金额：</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>费用：</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>低级输出：</translation>
    </message>
    <message>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>加上费用后:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>零钱</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>惯用的零钱地址</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>移除所有交易项</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>一次发送给多个接收者</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>添加接收人(&amp;R)</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>清除所有(&amp;A)</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>确认并付款</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>付款(&amp;E)</translation>
    </message>
    <message>
        <source>Enter a Gridcoin address (e.g. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</source>
        <translation>输入一个格雷德币地址(例如S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>复制金额</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>复制费用</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>复制转账金额加费用</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>复制比特数</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>复制低级输出</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>复制余额</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; to %2 (%3)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; 到 %2 (%3)</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>确认付款</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>您确定要付款 %1 吗?</translation>
    </message>
    <message>
        <source> and </source>
        <translation> 和 </translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>接收者地址不合法，请检查。</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>支付金额必须大于0。</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>金额超出您的账上余额。</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>计入 %1 交易费后的金额超出您的账上余额。</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>发现重复的地址, 每次只能对同一地址发送一次。</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>错误: 创建交易失败。</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>错误: 交易被拒绝. 如果您使用的是备份钱包，可能存在两个钱包不同步的情况，另一个钱包中的比特币已经被使用，但本地的这个钱包尚没有记录。</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>警告：无效的格雷德币地址</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>警告：未知的零钱地址</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>金额(&amp;M)</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>付给(&amp;T)：</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>消息：</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>标签(&amp;L)?</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>表单</translation>
    </message>
    <message>
        <source>The address to send the payment to  (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</source>
        <translation>付款地址 (例如:Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>从剪贴板粘贴地址</translation>
    </message>
    <message>
        <source>Send Custom Message to a Gridcoin Recipient</source>
        <translation>向格雷德币收款者发送常用消息</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>从地址薄选择地址</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>移除此接收者</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>为这个地址输入一个标签，以便将它添加到您的地址簿</translation>
    </message>
    <message>
        <source>Enter a Gridcoin address (e.g. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</source>
        <translation>请输入格雷德币地址 (例如:S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>签名 - 签名/验证一条消息</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>对消息签名(&amp;S)</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>您可以用你的地址对消息进行签名，以证明您是该地址的所有人。注意不要对模棱两可的消息签名，以免遭受钓鱼式攻击。请确保消息真实明确的表达了您的意愿。</translation>
    </message>
    <message>
        <source>The address to sign the message with (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</source>
        <translation>用来签名的格雷德币地址  (例如Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>从地址簿选择地址</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>从剪贴板粘贴地址</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>请输入您要发送的签名消息</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>复制当前签名至剪切板</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>发送签名消息以证明您是该格雷德币地址的拥有者</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>消息签名(&amp;M)</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>清空所有签名消息栏</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>清除所有(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>验证消息(&amp;V)</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>请在下面输入接收者地址、消息（确保换行符、空格符、制表符等完全相同）和签名以验证消息。请仔细核对签名信息，以提防中间人攻击。</translation>
    </message>
    <message>
        <source>The address the message was signed with (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</source>
        <translation>消息使用的签名地址 (例如Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>验证消息，确保消息是由指定的格雷德币地址签名过的</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>清空所有验证消息栏</translation>
    </message>
    <message>
        <source>Enter a Gridcoin address (e.g. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</source>
        <translation>输入一个格雷德币地址 (例如S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>单击“签名消息”产生签名。</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>输入格雷德币签名</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>输入的地址非法</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>请检查地址后重试。</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>输入的地址没有关联的公私钥对。</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>钱包解锁动作取消。</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>找不到输入地址关联的私钥。</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>消息签名失败。</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>消息已签名。</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>签名无法解码。</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>请检查签名后重试。</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>签名与消息摘要不匹配。</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>消息验证失败。</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>消息验证成功。</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>至 %1 个数据块时开启</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>冲突</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1 / 离线</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1 / 未确认</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 个确认</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>，未被成功广播</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>源</translation>
    </message>
    <message>
        <source>From</source>
        <translation>来自</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>To</source>
        <translation>到</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>自己的地址</translation>
    </message>
    <message>
        <source>label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>收入</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>未被接受</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>支出</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>交易费</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>净额</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>消息</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>备注</translation>
    </message>
    <message>
        <source>Gridcoin generated coins must mature 110 blocks before they can be spent. When you generated this block, it was broadcast to the network to be added to the block chain. If it fails to get into the chain, its state will change to "not accepted" and it won't be spendable. This may occasionally happen if another node generates a block within a few seconds of yours.</source>
        <translation>生成的格雷德币必须经过 110 个区块的成熟期后才可以使用。区块被生成后，它将被广播到网络中以加入区块链。如果它未能进入区块链，其状态将变为“未被接受”并且不可使用。有些时候，可能会有另一个节点比你早几秒钟成功生成一个区块，此时就可能发生这种情况。</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>金额</translation>
    </message>
    <message>
        <source>true</source>
        <translation>是</translation>
    </message>
    <message>
        <source>false</source>
        <translation>否</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>交易详情</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>当前面板显示了交易的详细信息</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>关闭(&amp;l)</translation>
    </message>
</context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>金额</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>直到 %1 后再打开</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>离线</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>未确认的 </translation>
    </message>
    <message>
        <source>Confirming (%1 of %2 recommended confirmations)&lt;br&gt;</source>
        <translation>确认中 (推荐 %2个确认，已经有 %1个确认)</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>已确认 (%1 条确认信息)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>冲突的</translation>
    </message>
    <message>
        <source>Immature (%1 confirmations, will be available after %2)&lt;br&gt;</source>
        <translation>未成熟 (%1 个确认，将在 %2 个后可用)&lt;br&gt;</translation>
    </message>
    <message>
        <source>This block was not received by any other nodes&lt;br&gt; and will probably not be accepted!</source>
        <translation>此数据块未被任何其他节点接收，可能不被接受！</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>已生成但未被接受</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>收款</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>收款来自</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>付款</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>付款给自己</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(不可用)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>交易状态。 鼠标移到此区域可显示确认项数量。</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>接收到交易的时间</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>交易类别。</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>转账目标地址</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>从余额添加或移除的金额。</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>这星期</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>这个月</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>上个月</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>今年</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>指定范围...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>收款</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>付款</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>给自己</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>挖矿所得</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>最小金额</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>复制金额</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>复制交易识别码</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>????</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>编辑标签</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>导出交易历史</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>已确认</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>金额</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>导出时出错</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>无法写入文件 %1 .</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>范围：</translation>
    </message>
    <message>
        <source>to</source>
        <translation>到</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>正在发送...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>当设置RPC端口%u以进行IPv6监听时出错，回到IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>设置RPC端口%u以监听IPv4:%s时出现错误</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>使用：</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>命令列表
</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>得到关于某个命令的帮助
</translation>
    </message>
    <message>
        <source>Gridcoin</source>
        <translation>格雷德币</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>警告：-paytxfee 被设置得非常高！若您发送一个转账，这是您将支付的转账费。</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>警告：wallet.dat损坏，数据已抢救! 原始的wallet.dat文件已在%s中保存为wallet.{timestamp}.bak.若您的余额或转账记录有误，您应该从备份中恢复。</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>警告： 读取wallet.dat时出现错误！所有密钥均已正确解读，但转账数据或地址簿条目可能缺失或不正确。</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>错误：交易创建失败 </translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>交易被拒绝。您钱包中的钱币可能已经被花费，例如当您使用wallet.dat文件的副本，钱币在该副本中被花费但未在这里标记为已花费时。</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>监听任意端口失败。 若您希望如此，使用 -listen=0.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>使用 %s 选项</translation>
    </message>
    <message>
        <source>%s, you must set a rpcpassword in the configuration file:
 %s
It is recommended you use the following random password:
rpcuser=gridcoinrpc
rpcpassword=%s
(you do not need to remember this password)
The username and password MUST NOT be the same.
If the file does not exist, create it with owner-readable-only file permissions.
It is also recommended to set alertnotify so you are notified of problems;
for example: alertnotify=echo %%s | mail -s "Gridcoin Alert" admin@foo.com
</source>
        <translation>%s,您必须在配置文件中设置RPC密码：
 %s
推荐您使用以下随机密码：
rpcuser=gridcoinrpc
rpcpassword=%s
(您无需记忆此密码)
用户名和密码绝对不能雷同。
若文件不存在，请新建并设置为仅所有者可读。
同样推荐设置alertnotify，这样当有问题时您会被通知到；
例如： alertnotify=echo %%s | mail -s "Gridcoin Alert" admin@foo.com
</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>您必须在配置文件
%s
中加入选项
rpcpassword=&lt;password&gt;
如果配置文件不存在，请新建，并将文件权限设置为仅允许文件所有者读取。</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>格雷德币版本</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>非法金额 -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>无效金额 -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Initialization sanity check failed. Gridcoin is shutting down.</source>
        <translation>初始化完整性检查失败。格雷德币正在停止运行。</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>钱包%s位于数据目录%s之外。</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>检查数据库完整性...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>初始化数据库环境 %s 时出错！为恢复，备份该目录，然后删除除wallet.dat之外的全部文件</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat损坏，抢救失败</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>无效的代理地址: '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>无效的 -tor 地址: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>无法解析 -bind 端口地址: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>无法解析 -externalip 地址: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>对-reservebalance=&lt;amount&gt; 无效的金额</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>blkindex.dat文件加载错误</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>wallet.dat钱包文件加载错误：钱包损坏</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>wallet.dat钱包文件加载错误：请升级到最新格雷德币客户端</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>钱包文件需要重写：请退出并重新启动格雷德币客户端</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>wallet.dat钱包文件加载错误</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>导入引导程序区块链数据文件。</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>正在加载地址...</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>错误: 无法启动节点</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>无法在本机绑定 %s 端口。比特币客户端软件可能已经在运行。</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>无法绑定本机端口 %s  (返回错误消息 %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>错误：钱包已锁定，不能创建交易</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>错误：钱包解锁仅用于权益增值，无法创建交易。</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>错误：转账需要至少 %s 的转账费，因为其数额，复杂度或使用了近期收到的存款  </translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>发送中...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>无效金额</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>警告：请确定您当前计算机的日期和时间是正确的！格雷德币将无法在错误的时间下正常工作。</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>警告：磁盘剩余空间低!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>被指定的是未知网络 -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>存款不足</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>加载区块索引...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>正在加载钱包...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>无法写入缺省地址</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>正在重新扫描...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>加载完成</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
</TS>